@@ -117,12 +117,12 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.9';
+	return '2.9.2';
   }
 
   function MinimumCMSVersion()
   {
-	return '1.8.1';
+	return '1.8.2';
   }
 
   function GetAdminDescription()
@@ -142,7 +142,7 @@ class Products extends CGExtensions
    ---------------------------------------------------------*/
   function GetHeaderHTML()
   {
-    $obj =& $this->GetModuleInstance('JQueryTools');
+	$obj = cge_utils::get_module('JQueryTools');
     if( is_object($obj) )
       {
 $tmpl = <<<EOT
