@@ -149,11 +149,12 @@ else
       }
   }
 
-if( !count($data) )
-  {
-    // nothing found in results
-    return;
-  }
+// if( !count($data) )
+//   {
+//     // nothing found in results
+//     return;
+//   }
+
 
 $hierdata = '';
 if( count($data) == 1 && empty($nodes) )
