@@ -80,7 +80,7 @@ if (file_exists(dirname(__FILE__)."/themes/${themeName}/${themeObjectName}.php")
      $themeObject = new AdminTheme($gCms, $userid, $themeName);
    }
 
-$gCms->variables['admintheme']=&$themeObject;
+//$gCms->variables['admintheme']=&$themeObject;
 if (isset($gCms->config['admin_encoding']) && $gCms->config['admin_encoding'] != '')
   {
     $themeObject->SendHeaders(isset($charsetsent), $gCms->config['admin_encoding']);
