@@ -71,6 +71,7 @@ $lang['detailtemplates'] = 'Detail Templates';
 $lang['detailtemplate_addedit'] = 'Add/Edit A Detail Template';
 $lang['dimensions'] = 'Dimensions';
 $lang['disabled'] = 'Disabled';
+$lang['down'] = 'Move Down';
 $lang['draft'] = 'Draft';
 $lang['dropdown'] = 'Dropdown';
 $lang['dropdown_options'] = 'Dropdown Options <em>(applicable only for dropdown fields)</em><br/><br/><em>(one entry per line)</em>';
@@ -448,6 +449,7 @@ $lang['title_summary_dflttemplate'] = 'Default New Summary Template';
 $lang['type'] = 'Type';
 
 # U
+$lang['up'] = 'Move Up';
 $lang['update'] = 'Update';
 $lang['upload'] = 'Select a file to upload';
 $lang['url_alias'] = 'URL Alias';
