@@ -39,9 +39,11 @@ $lang['categorylisttemplates'] = 'Gabarits de la liste des cat&eacute;gories';
 $lang['categorylisttemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit de liste de cat&eacute;gories';
 $lang['centimeters'] = 'Centim&egrave;tres';
 $lang['checkbox'] = 'Case &agrave; cocher';
+$lang['confirm_copyattributes'] = 'Aany existing attribute sets for this product will be removed. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'Confirmez-vous la suppression de cet &eacute;l&eacute;ment ? Tous les produits qui l&#039;utilisent ne figureront plus dans la hi&eacute;rarchie.';
 $lang['confirm_import'] = 'Voulez-vous r&eacute;ellement effectuer cette action ?\n\nDes param&egrave;tres incorrects ou un fichier de configuration invalide peuvent corrompre le catalogue de produits et le rendre inutilisable.';
 $lang['copy'] = 'Copier';
+$lang['copy_attrib_sets'] = 'Copy Attribute Sets';
 $lang['copy_category'] = 'Copier la cat&eacute;gorie';
 $lang['createddate'] = 'Date de cr&eacute;ation';
 $lang['current_value'] = 'Valeur actuelle';
@@ -53,11 +55,12 @@ $lang['delete'] = 'Supprimer';
 $lang['delete_attribset'] = 'Supprimer l&#039;attribut';
 $lang['delete_hierarchy_item'] = 'Supprimer un &eacute;l&eacute;ment de hi&eacute;rarchie';
 $lang['descending'] = 'Descendant';
-$lang['description'] = 'Un module pour g&eacute;rer un catalogue de produits, leur prix, images, etc, et pour permettre aux utilisateurs de cr&eacute;er un panier';
+$lang['description'] = 'Description ';
+$lang['destination'] = 'Destination ';
 $lang['details'] = 'D&eacute;tails';
 $lang['detailtemplates'] = 'Gabarits d&eacute;tails';
 $lang['detailtemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit d&eacute;tails';
-$lang['dimensions'] = 'Dimensions';
+$lang['dimensions'] = 'Dimensions ';
 $lang['disabled'] = 'D&eacute;sactiv&eacute;';
 $lang['draft'] = '&Eacute;bauche';
 $lang['dropdown'] = 'Menu d&eacute;roulant';
@@ -78,6 +81,7 @@ $lang['error_filenotfound'] = 'Fichier introuvable';
 $lang['error_fileopen'] = 'Erreur &agrave; l&#039;ouverture du fichier %s';
 $lang['error_invalidparent'] = 'Parent invalide (un element de hi&eacute;rarchie ne peut &ecirc;tre son propre parent)';
 $lang['error_invalid_name'] = 'La valeur du champ personnalis&eacute; est invalide (seuls les caract&egrave;res alphanum&eacute;riques sont autoris&eacute;s)';
+$lang['error_invalid_value'] = 'Invalid value specified';
 $lang['error_missingparam'] = 'Un param&egrave;tre requis est manquant ou invalide';
 $lang['error_nameused'] = 'Un &eacute;l&eacute;ment portant ce nom existe d&eacute;j&agrave;';
 $lang['error_nofieldtype'] = 'Choisisser le type du champ';
@@ -172,9 +176,11 @@ $lang['inches'] = 'Pouces';
 $lang['include_children'] = 'Avec les descendants ?';
 $lang['info_alnumonly'] = 'Caract&egrave;res alphanum&eacute;riques uniquement. Pas d&#039;espaces, de guillemets ou de combinaisons autres que lettres et chiffres.';
 $lang['info_attribtemplate'] = 'Les variables possibles sont : {$attrib_text},{$attrib_adjust},{$currency_symbol}';
+$lang['info_attributes_copied'] = 'Attributes Copied';
 $lang['info_autowatermark'] = 'La configuration des filigranes est celle du module CGExtensions';
 $lang['info_batchsize'] = 'Indiquez le nombre de lignes &agrave; traiter &agrave; chaque it&eacute;ration. D&egrave;s qu&#039;une it&eacute;ration est termin&eacute;e, le syst&egrave;me d&#039;importation d&eacute;marre la suivante. Si des probl&egrave;mes de m&eacute;moire ou de temps d&#039;ex&eacute;cution se produisent, r&eacute;duisez cette valeur, ou consultez le fournisseur de votre h&eacute;bergement.';
 $lang['info_cart_module_params'] = 'Ces param&egrave;tres sont pass&eacute;s au module panier s&eacute;lectionn&eacute;, &agrave; partir de la description et du r&eacute;sum&eacute; du produit.';
+$lang['info_copy_attribsets'] = 'This action will copy Attribute sets (excluding sku values) from another product.';
 $lang['info_createfields'] = 'Cr&eacute;er automatiquement les champs inconnus ? <em>(cr&eacute;ation de champs de type texte)</em>';
 $lang['info_createcategories'] = 'Cr&eacute;er automatiquement les cat&eacute;gories de produits pr&eacute;sentes dans le fichier CSV, si elles n&#039;existent pas d&eacute;j&agrave;';
 $lang['info_createhierarchy'] = 'Cr&eacute;er automatiquement les &eacute;l&eacute;ments de hi&eacute;rarchie de produits pr&eacute;sentes dans le fichier CSV, si ils n&#039;existent pas d&eacute;j&agrave;';
@@ -213,9 +219,16 @@ $lang['page_of'] = 'Page %s sur %s';
 $lang['page_limit'] = 'El&eacute;ments par page';
 $lang['param_action'] = 'Sp&eacute;cifie le comportement du module. Les valeurs possibles sont&nbsp;:
 <ul>
+  <li>hierarchy - Afficher la hi&eacute;rarchie de produits</li>
   <li>categorylist - Afficher une liste de cat&eacute;gories de produits</lI
   <li><em>default</em> - Affiche le sommaire des produits</li>
   <li>detail - Affiche le d&eacute;tail d&#039;un produit donn&eacute;</li>
+  <li>fieldlist - Affiche la liste des valeurs du champ sp&eacute;cifi&eacute;.
+     <p>
+&nbsp;&nbsp;&nbsp;&nbsp;- Cette action peut &ecirc;tre utilis&eacute;e pour cr&eacute;er une navigation &agrave; partir des valeurs d&#039;un champ sp&eacute;cifique. Par exemple, vous pouvez cr&eacute;er une liste d&eacute;roulante personnalis&eacute;e appel&eacute;e &quot;Couleur&quot; et alors cr&eacute;er une navigation bas&eacute;e sur les diff&eacute;rentes couleurs.
+     </p>
+  </li>
+  <li>search - Afficher un formulaire de recherche de produits multi-crit&egrave;res</li>
 </ul>';
 $lang['param_category'] = 'Lors de l&#039;utilisation <em>par d&eacute;faut</em> en mode sommaire, ce param&egrave;tre, qui devrait correspondre au nom d&#039;une cat&eacute;gorie existante, sera utilis&eacute; pour afficher seulement les entr&eacute;es qui sont dans cette cat&eacute;gorie (une liste s&eacute;par&eacute;e par des virgules peut &ecirc;tre fournie)';
 $lang['param_categorylisttemplate'] = 'Utile seulement avec l&#039;action categorylist, ce param&egrave;tre indique quel gabarit doit &ecirc;tre utilis&eacute; pour l&#039;affichage. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
@@ -265,6 +278,8 @@ $lang['product'] = 'Produit';
 $lang['productname'] = 'Nom du produit';
 $lang['products'] = 'Gestionnaire de produits';
 $lang['product_detail_settings'] = 'Param&egrave;tres D&eacute;tails du produit';
+$lang['product_editing_settings'] = 'Product Editing Settings';
+$lang['product_summary_settings'] = 'Product Summary Settings';
 $lang['product_hierarchy'] = 'Hierarchie de produits';
 $lang['product_manager'] = 'Gestionnaire de produits';
 $lang['progress'] = 'Progression';
@@ -304,7 +319,7 @@ $lang['prompt_notfound_404'] = 'G&eacute;n&eacute;rer une erreur 404';
 $lang['prompt_notfound_301'] = 'G&eacute;n&eacute;rer une redirection 301';
 $lang['prompt_notfound_errormsg'] = 'Afficher un message d&#039;erreur';
 $lang['prompt_notfound_msg'] = 'Message d&#039;erreur lorsqu&#039;un produit n&#039;est pas trouv&eacute;';
-$lang['prompt_notfound_page'] = 'Page pour faire les redirections permanantes';
+$lang['prompt_notfound_page'] = 'Page pour faire les redirections permanentes';
 $lang['prompt_prod_detailpage'] = 'Page par d&eacute;faut pour voir le d&eacute;tail des produits';
 $lang['prompt_products_matching'] = 'Produits correspondant &agrave; %s';
 $lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
@@ -333,6 +348,7 @@ $lang['select_one'] = 'Choisir...';
 $lang['sku'] = 'SKU (identifiant de quantit&eacute; en stock)';
 $lang['sort_by'] = 'Tri par';
 $lang['sort_order'] = 'Ordre de tri';
+$lang['source'] = 'Source';
 $lang['status'] = 'Statut';
 $lang['submit'] = 'Soumettre';
 $lang['subscription'] = 'Abonnement';
@@ -360,7 +376,7 @@ $lang['title_summary_dflttemplate'] = 'Gabarit par d&eacute;faut pour l&#039;aff
 $lang['type'] = 'Type ';
 $lang['update'] = 'Mise &agrave; jour';
 $lang['upload'] = 'Choisissez le fichier &agrave; envoyer';
-$lang['url_alias'] = 'URL Alias';
+$lang['url_alias'] = 'Alias URL ';
 $lang['valid'] = 'Valide';
 $lang['value'] = 'Valeur';
 $lang['values'] = 'Valeurs';
@@ -369,9 +385,9 @@ $lang['viewable_fields'] = 'S&eacute;lectionner les champs personnalis&eacute;s
 $lang['watermark_location'] = 'Emplacement du filigrane';
 $lang['weight'] = 'Poids';
 $lang['yes'] = 'Oui';
-$lang['qca'] = 'P0-1868798862-1289915740206';
-$lang['utmz'] = '156861353.1290510537.13.10.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
-$lang['utma'] = '156861353.1598479872.1289915740.1290510537.1290517279.14';
+$lang['utmz'] = '156861353.1291710225.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-747226238-1292160330212';
+$lang['utma'] = '156861353.1179877785.1291710225.1291927574.1292160330.5';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.2.10.1292160330';
 ?>
\ No newline at end of file
