@@ -198,7 +198,7 @@ class product_ops
     $done = false;
     if( $module->GetPreference('usehierpathurls',0) && !empty($product['alias']) && ($hier_id > 0) )
       {
-	$tmp = product_ops::get_hierarchy_info($hier_id);
+	$tmp = hierarchy_ops::get_hierarchy_info($hier_id);
 	if( $tmp )
 	  {
 	    $tmp2 = explode(' | ',$tmp['long_name']);
